==> editor-adapter-0.0.1.tgz: package/CodeMirrorEditor.js <==
import { computeSelector, executeInPage } from "./utils";
import { AbstractEditor } from "./AbstractEditor";
export class CodeMirrorEditor extends AbstractEditor {
    constructor(e) {
        super();
        this.elem = e;
        // Get the topmost ace element
        let parent = this.elem.parentElement;
        while (CodeMirrorEditor.matches(parent)) {
            this.elem = parent;
            parent = parent.parentElement;
        }
    }
    static matches(e) {
        let parent = e;
        for (let i = 0; i < 3; ++i) {
            if (parent !== undefined && parent !== null) {
                if ((/^(.* )?CodeMirror/gi).test(parent.className)) {
                    return true;
                }
                parent = parent.parentElement;
            }
        }
        return false;
    }
    getContent() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.getValue();
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    getCursor() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            const position = elem.CodeMirror.getCursor();
            return [position.line + 1, position.ch];
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    getElement() {
        return this.elem;
    }
    getLanguage() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.getMode().name;
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    setContent(text) {
        return executeInPage(`(${ /* istanbul ignore next */(selec, str) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.setValue(str);
        }})(${JSON.stringify(computeSelector(this.elem))}, ${JSON.stringify(text)})`);
    }
    setCursor(line, column) {
        return executeInPage(`(${ /* istanbul ignore next */(selec, l, c) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.getCursor(l - 1, c);
        }})(${JSON.stringify(computeSelector(this.elem))}, ${line}, ${column})`);
    }
}

==> editor-adapter-0.0.2.tgz: package/CodeMirrorEditor.js <==
import { computeSelector, executeInPage } from "./utils";
import { AbstractEditor } from "./AbstractEditor";
export class CodeMirrorEditor extends AbstractEditor {
    constructor(e) {
        super();
        this.elem = e;
        // Get the topmost ace element
        let parent = this.elem.parentElement;
        while (CodeMirrorEditor.matches(parent)) {
            this.elem = parent;
            parent = parent.parentElement;
        }
    }
    static matches(e) {
        let parent = e;
        for (let i = 0; i < 3; ++i) {
            if (parent !== undefined && parent !== null) {
                if ((/^(.* )?CodeMirror/gi).test(parent.className)) {
                    return true;
                }
                parent = parent.parentElement;
            }
        }
        return false;
    }
    getContent() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.getValue();
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    getCursor() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            const position = elem.CodeMirror.getCursor();
            return [position.line + 1, position.ch];
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    getElement() {
        return this.elem;
    }
    getLanguage() {
        return executeInPage(`(${ /* istanbul ignore next */(selec) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.getMode().name;
        }})(${JSON.stringify(computeSelector(this.elem))})`);
    }
    setContent(text) {
        return executeInPage(`(${ /* istanbul ignore next */(selec, str) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.setValue(str);
        }})(${JSON.stringify(computeSelector(this.elem))}, ${JSON.stringify(text)})`);
    }
    setCursor(line, column) {
        return executeInPage(`(${ /* istanbul ignore next */(selec, l, c) => {
            const elem = document.querySelector(selec);
            return elem.CodeMirror.setCursor({ line: l - 1, ch: c });
        }})(${JSON.stringify(computeSelector(this.elem))}, ${line}, ${column})`);
    }
}
